(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     10989,        304]
NotebookOptionsPosition[      8962,        262]
NotebookOutlinePosition[      9328,        278]
CellTagsIndexPosition[      9285,        275]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Conversion of file from Structure format to MMD format", "Subsection",
 CellChangeTimes->{{3.798272420866745*^9, 
  3.7982724610108433`*^9}},ExpressionUUID->"5915e70e-6e24-4b32-9bcd-\
a222a1d36ab3"],

Cell["\<\
The original file phased_HGDP+India+Africa_ 2810SNPs-regions1to36.stru \
contains diploid SNP genotypes. Pairs of alleles are given by consecutive \
lines\
\>", "Text",
 CellChangeTimes->{{3.798272529842943*^9, 
  3.798272598914424*^9}},ExpressionUUID->"61541a81-a92f-4b01-a510-\
b53088733704"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rawdata", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "\"\<phased_HGDP+India+Africa_2810SNPs-regions1to36.stru\>\"", ",", 
     "\"\<Table\>\""}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"length1", "=", 
    RowBox[{"Length", "[", "rawdata", "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Twice", " ", "the", " ", "number", " ", "of", " ", "individuals"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"length2", "=", 
    RowBox[{"Length", "[", 
     RowBox[{"rawdata", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Number", " ", "of", " ", "loci"}], " ", "+", " ", 
    RowBox[{"initial", " ", "rows"}]}], "*)"}]}]}], "Input",
 CellChangeTimes->{
  3.7982690912239513`*^9, {3.798272408935257*^9, 3.798272413141293*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"101deceb-9807-4292-a758-2e3df7c18c67"],

Cell[CellGroupData[{

Cell["Population names file (Human_ 2810SNP.pop)", "Subsubsection",
 CellChangeTimes->{{3.798272477154479*^9, 
  3.798272521139204*^9}},ExpressionUUID->"f0121ceb-c4cf-472a-9585-\
adfefc5b6026"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NamegrouplistAll", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"rawdata", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "[", 
      RowBox[{"[", "5", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6", ",", "length1", ",", "2"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"994b6cdd-f5b0-4a73-8b68-a883604e6699"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\<Human_2810SNP.pop\>\"", ",", "NamegrouplistAll", ",", "\"\<Text\>\""}],
   "]"}]], "Input",
 CellChangeTimes->{{3.798272284308922*^9, 3.7982723701661386`*^9}, 
   3.798276160215412*^9},
 CellLabel->"In[79]:=",ExpressionUUID->"c973cc70-6256-4757-8c1c-e0ca68270cff"],

Cell[BoxData["\<\"Human_2810SNP.pop\"\>"], "Output",
 CellChangeTimes->{3.798272334917109*^9, 3.798272371908719*^9, 
  3.7982761723726397`*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"ccccc58d-7aaf-4291-9d06-99bf87ee76a7"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Genotypes file in MMD format (Human_ 2810SNP.csv)", "Subsubsection",
 CellChangeTimes->{{3.79827296513914*^9, 
  3.798272988834324*^9}},ExpressionUUID->"7afb2fe4-8ae4-4108-b10f-\
cd25bc21fd64"],

Cell["\<\
Each line of the MMD formatted file contains 5620 loci corresponding to each \
pair of consecutive lines in the Structure file\
\>", "Text",
 CellChangeTimes->{{3.798273016353718*^9, 
  3.798273067089683*^9}},ExpressionUUID->"02c1eb8a-ea00-462c-95a5-\
9e34fab40a18"],

Cell[BoxData[
 RowBox[{
  RowBox[{"genotypes", "=", 
   RowBox[{"rawdata", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"6", ";;"}], ",", 
      RowBox[{"8", ";;"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7982691682662897`*^9, 3.79826922227689*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"789c581a-6d87-4a77-b8bd-4b630abe2041"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"genotypes", "=", 
   RowBox[{"genotypes", " ", "/.", 
    RowBox[{"{", 
     RowBox[{"\"\<A\>\"", "\[Rule]", " ", "\"\<1\>\""}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"genotypes", "=", 
   RowBox[{"genotypes", " ", "/.", 
    RowBox[{"{", 
     RowBox[{"\"\<T\>\"", "\[Rule]", " ", "\"\<2\>\""}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"genotypes", "=", 
   RowBox[{"genotypes", " ", "/.", 
    RowBox[{"{", 
     RowBox[{"\"\<G\>\"", "\[Rule]", " ", "\"\<3\>\""}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"genotypes", "=", 
   RowBox[{"genotypes", " ", "/.", 
    RowBox[{"{", 
     RowBox[{"\"\<C\>\"", "\[Rule]", " ", "\"\<4\>\""}], "}"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7982692644895773`*^9, 3.7982692660853777`*^9}, {
  3.798269783749628*^9, 3.798269828053989*^9}, {3.798269944345113*^9, 
  3.798269991718994*^9}, {3.798270023705688*^9, 3.798270026646172*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"3b3dfb6a-dc7b-42ce-861f-0f23623ba270"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "AllelesX", "]"}]], "Input",
 CellChangeTimes->{{3.798270324981552*^9, 3.7982703321705713`*^9}, {
  3.7982730773011*^9, 3.798273088002243*^9}, {3.798276232630538*^9, 
  3.7982762442663317`*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"f180a398-82b1-409d-9bae-c1be34122910"],

Cell[BoxData["1107"], "Output",
 CellChangeTimes->{
  3.798270334353611*^9, {3.798273078723879*^9, 3.798273088833391*^9}, 
   3.798276245007766*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"ef8ff045-568d-4965-a3b7-e05fae1d0ead"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"AllelesX", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"genotypes", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "genotypes", "]"}], ",", "2"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AllelesY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"genotypes", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", 
       RowBox[{"Length", "[", "genotypes", "]"}], ",", "2"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"joinAlleles", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"AllelesX", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"AllelesY", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "AllelesX", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.798270270900426*^9, 3.798270290629972*^9}, {
   3.7982703386765127`*^9, 3.798270355015752*^9}, 3.7982705270330963`*^9, {
   3.798270573573998*^9, 3.798270574037253*^9}, {3.798273420551363*^9, 
   3.79827352442139*^9}, {3.7982761965502567`*^9, 3.79827619933018*^9}, {
   3.798276250116053*^9, 3.798276255893943*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"a59acce0-6eeb-489c-8982-c7c41ab5ae0f"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"temp", "=", 
     RowBox[{
      RowBox[{"joinAlleles", "[", 
       RowBox[{"[", "i", "]"}], "]"}], " ", "/.", 
      RowBox[{"{", 
       RowBox[{"\"\<?\>\"", "\[Rule]", " ", 
        RowBox[{"ToString", "[", 
         RowBox[{"-", "i"}], "]"}]}], "}"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"joinAlleles", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "=", "temp"}], ";"}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "joinAlleles", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.798275029685211*^9, 3.7982751795071507`*^9}, 
   3.798284577639484*^9},
 CellLabel->"In[18]:=",ExpressionUUID->"39f7717b-fe02-4577-85a8-1fe4fe571715"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<Human_2810SNP.csv\>\"", ",", "joinAlleles", ",", 
   RowBox[{"\"\<TextDelimiters\>\"", "\[Rule]", "\"\<\>\""}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.736863568743281*^9, 3.736863580023015*^9}, {
   3.798273794370554*^9, 3.798273812597348*^9}, 3.79827407970505*^9, {
   3.79827489899791*^9, 3.79827490881885*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"05e668c9-91f9-4f6e-9ae7-b78e13cc0d85"],

Cell[BoxData["\<\"Human_2810SNP.csv\"\>"], "Output",
 CellChangeTimes->{3.798273858618596*^9, 3.798274127535246*^9, 
  3.798274954709659*^9, 3.7982752384650373`*^9, 3.798276316056809*^9, 
  3.79827636158774*^9, 3.798285855969372*^9, 3.798287652093101*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"d81bef08-5967-4a3d-9c63-6f8423554f09"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 822},
WindowMargins->{{256, Automatic}, {20, Automatic}},
Magnification:>1.25 Inherited,
FrontEndVersion->"12.0 for Linux x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 204, 3, 69, "Subsection",ExpressionUUID->"5915e70e-6e24-4b32-9bcd-a222a1d36ab3"],
Cell[787, 27, 304, 7, 75, "Text",ExpressionUUID->"61541a81-a92f-4b01-a510-b53088733704"],
Cell[1094, 36, 946, 27, 243, "Input",ExpressionUUID->"101deceb-9807-4292-a758-2e3df7c18c67"],
Cell[CellGroupData[{
Cell[2065, 67, 193, 3, 57, "Subsubsection",ExpressionUUID->"f0121ceb-c4cf-472a-9585-adfefc5b6026"],
Cell[2261, 72, 424, 12, 69, "Input",ExpressionUUID->"994b6cdd-f5b0-4a73-8b68-a883604e6699"],
Cell[CellGroupData[{
Cell[2710, 88, 321, 7, 39, "Input",ExpressionUUID->"c973cc70-6256-4757-8c1c-e0ca68270cff"],
Cell[3034, 97, 222, 3, 44, "Output",ExpressionUUID->"ccccc58d-7aaf-4291-9d06-99bf87ee76a7"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3305, 106, 199, 3, 57, "Subsubsection",ExpressionUUID->"7afb2fe4-8ae4-4108-b10f-cd25bc21fd64"],
Cell[3507, 111, 276, 6, 75, "Text",ExpressionUUID->"02c1eb8a-ea00-462c-95a5-9e34fab40a18"],
Cell[3786, 119, 352, 9, 39, "Input",ExpressionUUID->"789c581a-6d87-4a77-b8bd-4b630abe2041"],
Cell[4141, 130, 1073, 28, 127, "Input",ExpressionUUID->"3b3dfb6a-dc7b-42ce-861f-0f23623ba270"],
Cell[CellGroupData[{
Cell[5239, 162, 311, 5, 39, "Input",ExpressionUUID->"f180a398-82b1-409d-9bae-c1be34122910"],
Cell[5553, 169, 227, 4, 44, "Output",ExpressionUUID->"ef8ff045-568d-4965-a3b7-e05fae1d0ead"]
}, Open  ]],
Cell[5795, 176, 1510, 40, 127, "Input",ExpressionUUID->"a59acce0-6eeb-489c-8982-c7c41ab5ae0f"],
Cell[7308, 218, 801, 21, 98, "Input",ExpressionUUID->"39f7717b-fe02-4577-85a8-1fe4fe571715"],
Cell[CellGroupData[{
Cell[8134, 243, 451, 8, 69, "Input",ExpressionUUID->"05e668c9-91f9-4f6e-9ae7-b78e13cc0d85"],
Cell[8588, 253, 334, 4, 44, "Output",ExpressionUUID->"d81bef08-5967-4a3d-9c63-6f8423554f09"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

